Discover Packages
github.com/shivuslr41/grpc-tester
jq
package
Version:
v1.1.0
Opens a new window with list of versions in this module.
Published: Mar 29, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func Compare(r, e string, o bool) (bool, error)
func Extract(o, q string) (string, error)
func Filter(j string, q string) (string, error)
func Format(j string) (string, error)
func Replace(o, q, d string) (string, error)
Compare two JSON strings using the "jq --argjson" command-line tool.
Extract (select sub-objects) a JSON string using the "jq -rc" command-line tool.
similar to filter function but this returns raw format of JSON string.
Filter (select sub-objects) a JSON string using the "jq -c" command-line tool.
Format a JSON string using the "jq -s" command-line tool.
Replace a portion of a JSON string using the "jq" command-line tool.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.